@@ -2,13 +2,13 @@
 ########################################################
 # Call to Rcpp function
 ma.scale2 <- function (x , missings =FALSE ){ 
-    x_ <- base::as.matrix(x)
+    x_ <- as.matrix(x)
 	if ( ! missings ){
-		res <- base::.Call("scale2_C", x_, PACKAGE = "miceadds")
+		res <- scale2_C( x_ )
 	} else {
-		res <- base::.Call("scale2_NA_C", x_, PACKAGE = "miceadds")
+		res <- scale2_NA_C( x_ )
 	}
-	base::colnames(res) <- base::colnames(x)
-	base::return(res)
+	colnames(res) <- colnames(x)
+	return(res)
 }
-##########################################################
\ No newline at end of file
+##########################################################
